==> types_boto3_cloudcontrol-1.35.71-py3-none-any.whl: types_boto3_cloudcontrol/waiter.py <==
"""
Type annotations for cloudcontrol service client waiters.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudcontrol/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_cloudcontrol.client import CloudControlApiClient
    from types_boto3_cloudcontrol.waiter import (
        ResourceRequestSuccessWaiter,
    )

    session = Session()
    client: CloudControlApiClient = session.client("cloudcontrol")

    resource_request_success_waiter: ResourceRequestSuccessWaiter = client.get_waiter("resource_request_success")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys

from botocore.waiter import Waiter

from .type_defs import GetResourceRequestStatusInputResourceRequestSuccessWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ResourceRequestSuccessWaiter",)


class ResourceRequestSuccessWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudcontrol/waiter/ResourceRequestSuccess.html#CloudControlApi.Waiter.ResourceRequestSuccess)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudcontrol/waiters/#resourcerequestsuccesswaiter)
    """

    def wait(
        self, **kwargs: Unpack[GetResourceRequestStatusInputResourceRequestSuccessWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudcontrol/waiter/ResourceRequestSuccess.html#CloudControlApi.Waiter.ResourceRequestSuccess.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudcontrol/waiters/#resourcerequestsuccesswaiter)
        """

==> types_boto3_cloudcontrol-1.39.0-py3-none-any.whl: types_boto3_cloudcontrol/waiter.py <==
"""
Type annotations for cloudcontrol service client waiters.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudcontrol/waiters/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_cloudcontrol.client import CloudControlApiClient
    from types_boto3_cloudcontrol.waiter import (
        ResourceRequestSuccessWaiter,
    )

    session = Session()
    client: CloudControlApiClient = session.client("cloudcontrol")

    resource_request_success_waiter: ResourceRequestSuccessWaiter = client.get_waiter("resource_request_success")
    ```
"""

from __future__ import annotations

import sys

from botocore.waiter import Waiter

from .type_defs import GetResourceRequestStatusInputWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ResourceRequestSuccessWaiter",)


class ResourceRequestSuccessWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudcontrol/waiter/ResourceRequestSuccess.html#CloudControlApi.Waiter.ResourceRequestSuccess)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudcontrol/waiters/#resourcerequestsuccesswaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[GetResourceRequestStatusInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudcontrol/waiter/ResourceRequestSuccess.html#CloudControlApi.Waiter.ResourceRequestSuccess.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudcontrol/waiters/#resourcerequestsuccesswaiter)
        """
